# encoding: utf8

from setuptools import setup


setup(
    author='Ionel Cristian M\xc4\x83rie\xc8\x99',
    author_email='contact@ionelmc.ro',
    description='A fast and thorough lazy object proxy',
    install_requires=['lazy-object-proxy'],
    long_description='''Use `lazy-object-proxy <https://pypi.python.org/pypi/lazy-object-proxy/>`_ instead.''',
    maintainer='Ionel Cristian M\xc4\x83rie\xc8\x99',
    maintainer_email='contact@ionelmc.ro',
    name='lop',
    platforms=['all'],
    py_modules=['wheel-platform-tag-is-broken-on-empty-wheels-see-issue-141'],
    url='https://pypi.python.org/pypi/lazy-object-proxy/',
    version="0.0",
    zip_safe=False,
)
